@@ -1,6 +1,6 @@
-use derive_debug_extras::DebugMore;
+use derive_debug_extras::DebugExtras;
 
-#[derive(DebugMore)]
+#[derive(DebugExtras)]
 #[debug_single_tuple_inline]
 struct A(pub u32);
 
@@ -9,7 +9,7 @@ fn struct_tuple_inline() {
     assert_eq!(format!("{:#?}", A(154)), "A(154)");
 }
 
-#[derive(DebugMore)]
+#[derive(DebugExtras)]
 #[debug_single_tuple_inline]
 enum B {
     X(String),
@@ -22,7 +22,7 @@ fn enum_tuple_inline() {
     assert_eq!(format!("{:#?}", B::Y(123.1)), "B::Y(123.1)");
 }
 
-#[derive(DebugMore)]
+#[derive(DebugExtras)]
 struct C {
     x: u32,
     #[debug_ignore]
@@ -34,7 +34,7 @@ fn debug_ignore_field() {
     assert_eq!(format!("{:?}", C { x: 12, _y: false }), "C { x: 12 }");
 }
 
-#[derive(DebugMore)]
+#[derive(DebugExtras)]
 struct D {
     #[debug_as_display]
     x: String,
